*: File: SYSBEEP.PRG
*
*
*	This function accesses MS Windows MessageBeep call. The MessageBeep call
*	plays a waveform sound [.wav files] corresponding to a given system alert level. The 
*	sound for each alert level is identified by an entry in the [sounds] section of the
*	WIN.INI initialization file.
*
*	If "Enable System Sounds" is checked in the Sounds application of the Windows 
*	Control Panel and your program attempts to sound a beep by using the FoxPro
*	commands: ??CHR(7), generally nothing happens. Sounding a beep with this 
*	function will play the sound.
*
*	The MS Windows MessageBeep call returns control to the calling program after queuing
*	the sound and plays the sound asynchronously.
*
*	If it cannot play the specified alert sound, MessageBeep attempts to play the system
*	default sound. If it cannot play the system default sound, the function produces a
*	standard beep sound by using the computer speaker.
*
*	The program user can disable the warning beep by using the Windows Control Panel
*	application Sounds. 
*
*	Much of the above is from the Windows v3.1 SDK.
*	
******************************************************************
* FUNCTION: Beep(lcType)
*
* 	lcType:	RegBeep	Produces a standard beep sound by 
*						using the computer speaker.
*			*			Plays the sound identified by the 
*						SystemAsterisk entry in the [sounds]
*						section of WIN.INI.
*			!			Plays the sound identified by the 
*						SystemExclamation entry in the [sounds]
*						section of WIN.INI.
*			?			Plays the sound identified by the 
*						SystemQuestion entry in the [sounds]
*						section of WIN.INI.
*			Hand		Plays the sound identified by the 
*						SystemHand entry in the [sounds]
*						section of WIN.INI.
*			Ok			Plays the sound identified by the 
*						SystemDefault entry in the [sounds]
*						section of WIN.INI.
*
*	Return value: This function does not return a value
*
*
*	FoxPro version: 2.5a
*
*	Required library: foxtools.fll
*
*	Before attempting to use this function change the definition string for c_FoxToolsFile
*	to the drive and path where foxtools.fll is located on your system. Then compile
*	this program.
*
*	Address comments and suggestions to:	J. Lincoln Barr
*											Compuserve ID: 74010,1032
*
*
*	15 August, 1993
*
******************************************************************

FUNCTION Beep
	PARAMETER lcType
	PRIVATE lcType, msgH, lnType
	
IF PARAMETERS() = 0
	WAIT WINDOW "lcType=RegBeep,*,!,?,Hand,Ok"
	RETURN
ENDIF

#define	c_FoxToolsFile	"D:\BINW\FOXPROW\FOXTOOLS.FLL"

#define	RegBeep	-1
#define	Ok			0
#define	Hand		16
#define	Question	32
#define	Exclaim		48
#define	Asterisk		64

	DO CASE
		CASE UPPER(lcType) == "REGBEEP"
			lnType = RegBeep
			
		CASE UPPER(lcType) == "OK"
			lnType = Ok
			
		CASE UPPER(lcType) == "HAND"
			lnType = Hand
			
		CASE UPPER(lcType) == "?"
			lnType = Question
			
		CASE UPPER(lcType) == "!"
			lnType = Exclaim
			
		CASE UPPER(lcType) == "*"
			lnType = Asterisk
			
		OTHERWISE
			WAIT WINDOW "Unknown lcType"
			
	ENDCASE

	SET LIBRARY TO c_FoxToolsFile ADDITIVE

	msgH = RegFn("MessageBeep","I", "I")

	=CallFn(msgH, lnType)

	RELEASE LIBRARY c_FoxToolsFile

RETURN

*: EOF: SYSBEEP.PRG
		

		